package com.ruoyi.system.service.projectV2.common;

import com.ruoyi.system.domain.projectV2.common.ChinaArea;

import java.util.List;

/**
 * 中国行政规划Service接口
 * 
 * @author boman
 * @date 2023-03-28
 */
public interface IChinaAreaService 
{
    /**
     * 查询中国行政规划
     * 
     * @param areaId 中国行政规划主键
     * @return 中国行政规划
     */
    public ChinaArea selectChinaAreaByAreaId(String areaId);

    /**
     * 查询中国行政规划列表
     * 
     * @param chinaArea 中国行政规划
     * @return 中国行政规划集合
     */
    public List<ChinaArea> selectChinaAreaList(ChinaArea chinaArea);

    /**
     * 新增中国行政规划
     * 
     * @param chinaArea 中国行政规划
     * @return 结果
     */
    public int insertChinaArea(ChinaArea chinaArea);

    /**
     * 修改中国行政规划
     * 
     * @param chinaArea 中国行政规划
     * @return 结果
     */
    public int updateChinaArea(ChinaArea chinaArea);

    /**
     * 批量删除中国行政规划
     * 
     * @param areaIds 需要删除的中国行政规划主键集合
     * @return 结果
     */
    public int deleteChinaAreaByAreaIds(String[] areaIds);

    /**
     * 删除中国行政规划信息
     * 
     * @param areaId 中国行政规划主键
     * @return 结果
     */
    public int deleteChinaAreaByAreaId(String areaId);
}
